package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````4&H```````!``````````."*````
M`````````$``.``+`$``'@`=``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!````````````````````````````````````%!:````````4%H`````````
M$`````````$````%````4%H```````!0:@```````%!J````````8"D`````
M``!@*0`````````0`````````0````8```"P@P```````+"C````````L*,`
M``````"(`@```````%`,`````````!`````````!````!@```#B&````````
M.+8````````XM@```````/`!````````%`(`````````$`````````(````&
M````*(0````````HI````````"BD````````L`$```````"P`0````````@`
M````````4N5T9`0```"P@P```````+"C````````L*,```````"(`@``````
M`%`,`````````0````````!0Y71D!````.15````````Y%4```````#D50``
M`````-P`````````W``````````$`````````%'E=&0&````````````````
M````````````````````````````````````````````````````!`````0`
M``#$`@```````,0"````````Q`(```````!$`````````$0`````````!```
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!`````!````
M1TY5```````$```````````````$````%`````,```!'3E4`.O3?)L_.+">_
M8GI:W\:1;!I%]=`````````````````````````````````!````$@``````
M```````````````````3````(``````````````````````````B````(```
M```````````````````````^````(`````````````````````````!8````
M(@````````````````````````!G````%@````````````````````````!Z
M````$@````````````````````````"*````$@``````````````````````
M``"5````$@````````````````````````"<````$@``````````````````
M``````"D````$@````````````````````````"M````$@``````````````
M``````````"T````$@````````````````````````"[````$@``````````
M``````````````#,````$@````````````````````````#3````$@``````
M``````````````````#:````$@````````````````````````#A````$@``
M``````````````````````#H````$@````````````````````````#O````
M$@````````````````````````#V````$@````````````````````````#]
M````$0`````````````````````````%`0``$@``````````````````````
M```-`0``$@`````````````````````````5`0``$@``````````````````
M```````=`0``$@`````````````````````````D`0``$@``````````````
M```````````K`0``$@`````````````````````````T`0``$@``````````
M```````````````Z`0``$@````````````````````````!+`0``$0``````
M``````````````````!2`0``$@````````````````````````!:`0``$@``
M``````````````````````!A`0``$@````````````````````````!I`0``
M$@````````````````````````!N`0``$@````````````````````````!U
M`0``$@````````````````````````!Z`0``$@``````````````````````
M``""`0``$@````````````````````````"*`0``$@``````````````````
M``````"4`0``$@````````````````````````";`0``$@``````````````
M``````````"D`0``$@````````````````````````"J`0``$@``````````
M``````````````"Z`0``$@````````````````````````#(`0``$@``````
M``````````````````#4`0``$@````````````````````````#@`0``$@``
M``````````````````````#U`0``$@`````````````````````````$`@``
M$@`````````````````````````5`@``$@`````````````````````````H
M`@``$0`````````````````````````U`@``$@``````````````````````
M``!``@``$@````````````````````````!%`@``$@``````````````````
M``````!4`@``$@````````````````````````!G`@``$@``````````````
M``````````!R`@``$@````````````````````````![`@``$@``````````
M``````````````")`@``$@````````````````````````"3`@``$@``````
M``````````````````"A`@``$@````````````````````````"R`@``$@``
M``````````````````````"Z`@``$@````````````````````````````(`
M`0`!``$``P`!``$``0`#``,``P`#``0`!0`#``,``P`#``,`!@`#``,``P`#
M``,``P`#``,``P`#``,``P`#``,``P`#``,`!@`#``,``P`#``,``0`!``$`
M`0`!``$``0`!``$``0`#``$``0`!``$``0`!``$``0`#``<````!``8`S`(`
M`!``````````=1II"0```P#6`@``$````'(9:0D```<`X@(``!`````4:6D-
M```%`.X"```0````E)&6!@``!`#X`@``$````+.1E@8```8``P,``!````"T
MD98&```"``X#``````````````$```!!`````0```!H`````````````````
M````7U]L:6)C7W-T87)T7VUA:6X`7U]G;6]N7W-T87)T7U\`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`
M7U]C>&%?9FEN86QI>F4`4$Q?8W5R<F5N=%]C;VYT97AT`&)O;W1?1'EN84QO
M861E<@!097)L7VYE=UA3`&=E='!I9`!S<')I;G1F`')E861L:6YK`&UA;&QO
M8P!M96UC<'D`7U]S=&%C:U]C:&M?9F%I;`!S=')S='(`<W1R9'5P`'-T<G1O
M:P!S=')C;7``<W1R;&5N`'-T870V-`!A8V-E<W,`96YV:7)O;@!R96%L;&]C
M`&UE;6UO=F4`<W1R<F-H<@!S=')C<'D`9V5T=6ED`&=E='!W=6ED`&UK9&ER
M`%]?97)R;F]?;&]C871I;VX`<W1D97)R`&9P<FEN=&8`;W!E;C8T`&QS965K
M-C0`<F5A9`!M96UC;7``9G)E90!L<W1A=#8T`&]P96YD:7(`<F5A9&1I<C8T
M`'5N;&EN:P!C;&]S961I<@!R;61I<@!097)L7V=V7V9E=&-H<'8`4&5R;%]S
M=E]S971P=@!097)L7VUG7W-E=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`%!E<FQ?
M871F;W)K7W5N;&]C:P!03%]D;U]U;F1U;7``<&5R;%]A;&QO8P!E>&ET`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E
M<FQ?<G5N`'!E<FQ?9&5S=')U8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`
M4&5R;%]N97=84U]F;&%G<P!S=')N8VUP`%]?<F5G:7-T97)?871F;W)K`&QI
M8F,N<V\N-@!'3$E"0U\R+C(N-0!'3$E"0U\R+C,N,@!'3$E"0U\R+C0`1TQ)
M0D-?,BXQ-`!'3$E"0U\R+C,S`$=,24)#7S(N,S0`;&EB<&5R;"YS;RXU+C0P
M`````+"C````````"`````````#P:@```````+BC````````"``````````P
M:P```````,"C````````"`````````!S%0```````,BC````````"```````
M``"!%0```````."C````````"`````````!I%@```````.BC````````"```
M```````T%@```````/"C````````"`````````#T%@```````/BC````````
M"``````````8%P````````"D````````"`````````!<%0```````!"D````
M````"`````````#7%@```````!BD````````"`````````!950```````#BV
M````````"``````````XM@```````$"V````````"``````````=%P``````
M`$BV````````"`````````!_%0```````%"V````````"`````````!E%@``
M`````-BE````````!@````$``````````````."E````````!@````(`````
M`````````.BE````````!@````,``````````````/"E````````!@````0`
M`````````````/BE````````!@````4```````````````"F````````$@``
M``8```````````````BF````````!@````<``````````````!"F````````
M!@```!8``````````````!BF````````!@```!\``````````````""F````
M````!@```#(``````````````"BF````````!@```#,``````````````#"F
M````````!@```#0``````````````("V````````!P````4`````````````
M`(BV````````!P````@``````````````)"V````````!P````D`````````
M`````)BV````````!P````H``````````````*"V````````!P````L`````
M`````````*BV````````!P````P``````````````+"V````````!P````T`
M`````````````+BV````````!P````X``````````````,"V````````!P``
M``\``````````````,BV````````!P```!```````````````-"V````````
M!P```!$``````````````-BV````````!P```!(``````````````."V````
M````!P```!,``````````````.BV````````!P```!0``````````````/"V
M````````!P```!4``````````````/BV````````!P```!<`````````````
M``"W````````!P```!@```````````````BW````````!P```!D`````````
M`````!"W````````!P```!H``````````````!BW````````!P```!L`````
M`````````""W````````!P```!P``````````````"BW````````!P```!T`
M`````````````#"W````````!P```!X``````````````#BW````````!P``
M`"```````````````$"W````````!P```"$``````````````$BW````````
M!P```"(``````````````%"W````````!P```",``````````````%BW````
M````!P```"0``````````````&"W````````!P```"4``````````````&BW
M````````!P```"8``````````````'"W````````!P```"<`````````````
M`'BW````````!P```"@``````````````("W````````!P```"D`````````
M`````(BW````````!P```"H``````````````)"W````````!P```"L`````
M`````````)BW````````!P```"P``````````````*"W````````!P```"T`
M`````````````*BW````````!P```"X``````````````+"W````````!P``
M`"\``````````````+BW````````!P```#```````````````,"W````````
M!P```#$``````````````,BW````````!P```#4``````````````-"W````
M````!P```#8``````````````-BW````````!P```#<``````````````."W
M````````!P```#@``````````````.BW````````!P```#D`````````````
M`/"W````````!P```#H``````````````/BW````````!P```#L`````````
M``````"X````````!P```#P```````````````BX````````!P```#T`````
M`````````!"X````````!P```#X``````````````!BX````````!P```#\`
M`````````````""X````````!P```$```````````````"XO<&5R;'AS:2YC
M``!#04-(10``0TQ%04X`,2XP-3<`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`E<R\E
M<P!);G1E<FYA;',Z.E!!4CHZ0D]/5`!435``4$%27U1%35``4$%27T-!0TA%
M`"]T;7``4UE35$5-`"\`+@``+W!R;V,O)6DO)7,`56YA8FQE('1O(&-R96%T
M92!C86-H92!D:7)E8W1O<GD`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H`4$523$E/`'!E<FP`97AE`%!%4DPU3U!4`!@`4$%2
M7T=,3T)!3%]#3$5!3@!435!$25(`4$%42``N+@!005)?0TQ%04X`<&%R;``N
M<&%R`"5S)7-T96UP+25U)7,`.@`Q`%!!4E]435!$25(`)7,E<W1E;7`M)74M
M)74E<P!P87(M`"UE`%!!4E])3DE424%,25I%1``E<R5S)7,E<P!005(Z.E!A
M8VME<CHZ5D524TE/3@`M+0`P`%!!4E]04D]'3D%-10!005)?1$5"54<`55-%
M4@`E<R5S)7,`4$%27T=,3T)!3%]$14)51P!414U01$E2`%!!4E]34$%73D5$
M`%!!4E]'3$]"04Q?5$5-4`!414U0`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@
M>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ
M92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD
M4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA
M9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P
M,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S
M:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%
M.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P
M;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L
M("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I
M(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D
M<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$[
M"GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L
M94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N
M86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*
M8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@
M(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/
M3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@
M/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/
M(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?
M9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G
M+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]
M("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.
M5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?
M<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\
M.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F
M:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET
M(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O
M<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I
M('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)
M0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H
M(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E
M96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG
M=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#
M04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#
M3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@
M34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`[
M"G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E
M="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R
M="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?
M1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E
M860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@
M<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C
M:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL
M;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY
M("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH
M7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@
M(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S
M879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H
M("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA
M;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<
M;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L
M(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I
M(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@
M)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@
M)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M
M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!
M4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F
M:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T
M92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H
M)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]
M"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]
M+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M
M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M
M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T
M(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE
M;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA
M;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E
M('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T
M;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA
M;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO
M('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N
M86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@
M;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N
M9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M
M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*
M)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE
M('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68[
M"G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A
M<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P
M:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$
M5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q
M6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H
M*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD
M968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*
M:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D
M=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH
M)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB
M97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,[
M"FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?
M<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#
M;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT
M('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN
M960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N
M*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]
M"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM
M>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I
M;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN
M97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@
M(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@
M;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B
M)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD
M9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y
M*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-2
M0S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E
M9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@
M(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A
M7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@
M>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S
M=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE
M>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@
M,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D
M8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@
M)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM
M;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@
M)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ
M1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV
M93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@
M)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G
M;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I
M.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M
M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@
M;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA
M;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6
M.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L
M92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;
M+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@
M>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY
M("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF
M:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H
M.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[
M(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E
M(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR
M97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI
M=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I
M<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U
M:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5
M;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@
M7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$[
M"G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@
M<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W
M*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64[
M"FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@
M9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I
M("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H
M9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@
M>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\
M("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2![
M"B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H
M+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P
M<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?
M;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&
M24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B
M=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B
M=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)
M3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N
M86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE
M.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B([
M"GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D
M:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D
M:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD
M<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@
M)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?
M=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP
M;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ
M<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@
M*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M
M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M
M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D
M=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O
M9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$[
M"GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I
M;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O
M<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA
M;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER
M("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN
M97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6
M>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H
M)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M
M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE
M+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D[
M"B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P
M=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?
M24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!
M4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@
M97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?
M5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S
M('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G
M9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI
M=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN
M960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X
M<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2
M.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H
M0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C
M<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN
M70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X
M:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X
M:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`
M4$523$Q)0@!,1%],24)205)97U!!5$@`55-%4DY!344`)7,Z('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A
M;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@`E<R5S8V%C:&4M)7,E<P!015),
M-4Q)0@!005)?1TQ/0D%,7U1-4$1)4@`E,#)X``$;`SO8````&@```&P4``#T
M````7!4``"`!``"L%0``0`$``/P6``!D`0``#!<``(0!``#\&0``J`$``$P:
M``#,`0``/!T``/`!``",'0``$`(``%P?```T`@``K"```%0"```\(0``>`(`
M`(PA``"8`@``W"$``+@"``#,(@``V`(``-PL``#\`@``G"T``"`#``!L+@``
M1`,``,PO``!H`P``/#```(@#```<,@``K`,``%PU``#,`P``##@``/`#``!\
M.```$`0``)PY```P!```/#H``%`$```4``````````%Z4@`!>!`!&PP'")`!
M!Q`0````'````'`3```B`````````!0``````````7I2``%X$`$;#`<(D`$`
M`!P````<````-!0``$(`````00X0A@)##09]#`<(````(````#P```!D%```
M10$```!!#A"&`D,-!@,[`0P'"$$,!A``'````&````"0%0``"P````!!#A"&
M`D,-!D8,!P@````@````@````(`5``#C`@```$$.$(8"0PT&`]D"#`<(00P&
M$``@````I````$P8``!+`````$$.$(8"0PT&`D$,!PA!#`80```@````R```
M`'@8``#P`@```$$.$(8"0PT&`^8"#`<(00P&$``<````[````$0;``!/````
M`$$.$(8"0PT&`DH,!P@``"`````,`0``=!L``,(!````00X0A@)##08#N`$,
M!PA!#`80`!P````P`0``(!T``$$!````00X0A@)##08#/`$,!P@`(````%`!
M``!0'@``BP````!!#A"&`D,-!@*!#`<(00P&$```'````'0!``"\'@``4```
M``!!#A"&`D,-!@)+#`<(```<````E`$``.P>``!$`````$$.$(8"0PT&?PP'
M"````!P```"T`0``'!\``.@`````00X0A@)##08"XPP'"```(````-0!``#L
M'P``!@H```!!#A"&`D,-!@/\"0P'"$$,!A``(````/@!``#8*0``O@````!!
M#A"&`D,-!@*T#`<(00P&$```(````!P"``!T*@``R@````!!#A"&`D,-!@+`
M#`<(00P&$```(````$`"```@*P``7P$```!!#A"&`D,-!@-5`0P'"$$,!A``
M'````&0"``!<+```;0````!!#A"&`D,-!@)H#`<(```@````A`(``*PL``#3
M`0```$$.$(8"0PT&`\D!#`<(00P&$``<````J`(``&@N```Q`P```$$.$(8"
M0PT&`RP##`<(`"````#(`@``B#$``*X"````00X0A@)##08#I`(,!PA!#`80
M`!P```#L`@``%#0``&,`````00X0A@)##08"7@P'"```'`````P#``!D-```
M&P$```!!#A"&`D,-!@,6`0P'"``<````+`,``&0U``"5`````$$.$(8"0PT&
M`I`,!P@``!0```!,`P``Y#4```P````````````````````Q[4F)T5Y(B>)(
M@^3P4%1%,<`QR4B-/=4@``#_%6<[``#TS,S,S,S,S,S,S,S,S,Q(C3VQ2P``
M2(T%JDL``$@Y^'052(L%3CL``$B%P'0)_^`/'X``````PP\?@`````!(C3V!
M2P``2(TU>DL``$@I_DB)\$C![C](P?@#2`'&2-'^=!1(BP45.P``2(7`=`C_
MX&8/'T0``,,/'X``````\P\>^H`]+4T```!U*U5(@SWR.@```$B)Y70,2(L]
M)DL``.A))0``Z&3____&!05-```!7<,/'P###Q^``````/,/'OKI=____\S,
MS,S,S,Q52(GE2(/L$$B)??A(BPVM.@``9$B+!"4`````2`'(2(LX2(TU2*K_
M_TB+%9@Z``!(C0UIJ?__Z/0D``!(@\007<-F9F9F9BX/'X0``````%5(B>5(
M@>Q0(```9$B+!"4H````2(E%^$C'A=#?__\`````2(V%\.___TB)A<#?___H
MNB0``$B+O<#?__^)PDB--:ZI__](C0TWJO__L`#HK"0``(F%S-___X.]S-__
M_P!]$$C'A=C?__\`````Z9T```!(C;WP[___2(VUX-___[H`$```Z(4D``")
MA<S?__^#O<S?__\`?0U(QX78W___`````.MIBX7,W___@\`!2&/XZ&@D``!(
MB870W___2(.]T-___P!U#4C'A=C?__\`````ZSI(B[W0W___2(VUX-___TAC
ME<S?___H0"0``$B+A=#?__](8XW,W___Q@0(`$B+A=#?__](B878W___2(N%
MV-___TB)A;C?__]D2(L$)2@```!(BTWX2#G(=1!(BX6XW___2('$4"```%W#
MZ/LC``!F9BX/'X0``````%5(B>7HI_[__UW##Q]$``!52(GE2('L\!```&1(
MBP0E*````$B)1?A(B;U0[___2(FU2.___TB-/4.H___HO@(``$B)A3#O__](
MB[U0[___2(LU$4D``.BD(P``2(/X`'0F2(NU4.___TB-/7"I___HVP(``$B+
MA5#O__](B858[___Z38"``!(B[U([___Z'PC``!(B<=(BS722```Z'TC``!(
MB85`[___2(.]0.___P`/A.4!``!(BX5`[___#[X`@_@`=0Y(C073I___2(F%
M0.___TB#O3#O__\`=!U(B[TP[___2(NU0.___^@^(P``@_@`=07IA0$``$B+
MA4#O__](B84H[___2(N]0.___^@J(P``2(G!2(N%*.___T@!R$B#P/](B84X
M[___2(N-0.___S'`2#N-..___XB%)^___W,?2(N%..___P^^`$B+#1%(```/
MO@DYR`^4P(B%)^___XJ%)^___Z@!=0+K'DB+A3CO___&``!(BX4X[___2(/`
M_TB)A3CO___KGTB+O4#O___HI2(``$B#P`%(B848[___2(N]4.___^B.(@``
M2(G!2(N%&.___T@!R$@]`!```'(F2(NU4.___TB-/0NH___H=@$``$B+A5#O
M__](B858[___Z=$```!(C;WP[___2(N50.___TB+#69'``!,BX50[___2(TU
M[*?__[``Z)DA``!(C;WP[___2(VU8.___^@F(@``@_@`=5"+A7CO__\E`/``
M`#T`@```=3Y(C;WP[___O@$```#H#B(``(/X`'4H2(VU\.___TB-/7NG___H
MY@```$B-O?#O___HFB$``$B)A5CO___K/^L`2(LUZ$8``#'`B<?HCR$``$B)
MA4#O___I#?[__TB+M5#O__](C3TUI___Z*````!(BX50[___2(F%6.___TB+
MA5CO__](B840[___9$B+!"4H````2(M-^$@YR'402(N%$.___TB!Q/`0``!=
MP^C](```9F9F9BX/'X0``````%5(B>5(@^P@9$B+!"4H````2(E%^$B)?>A(
MBWWH2(UU].A:'@``2(E%X&1(BP0E*````$B+3?A(.<AU"DB+1>!(@\0@7</H
MI2````\?1```54B)Y4B#[%!D2(L$)2@```!(B47X2(E]Z$B)=>!(BT7@#[X`
M@_@]=0Q(BT7@2(/``4B)1>!(BWW@Z+(@``!(B4702(M]Z$B-=?3HX1T``$B)
M1=A(@_@`=$I(BWW8Z(X@``!(.T70<C;K`$B+1>!(B<%(@\$!2(E-X(H`2(M-
MV$B)RDB#P@%(B578B`$\`'0"Z]C'1?``````Z2P"``#I`@$``$B+!38U``!(
MBP!(B47`QT7,`````$B+1<!(@S@`=!GK`$B+1<!(@\`(2(E%P(M%S(/``8E%
MS.O=@STV1P```'1$2(L%]30``$B+.(M%S(/``DAC\$C!Y@/H("```$B)P4B+
M!=8T``!(B0A(BP7,-```2(,X`'4,QT7P_____^FD`0``ZUS'!>9&```!````
MBT7,@\`"2&/X2,'G`^@\'P``2(E%P$B#?<``=0S'1?#_____Z6\!``!(BWW`
M2(L%>C0``$B+,$AC5<Q(P>(#Z+H?``!(BTW`2(L%7S0``$B)"$B+!54T``!(
MBP"+3<R#P0%(8\E(QP3(`````(M%S(E%]$B+1>A(B4782(M%V`^^"#'`@_D`
MB$6_=!!(BT78#[X`@_@]#Y7`B$6_BD6_J`%U`NL0ZP!(BT782(/``4B)1=CK
MQDB+1=A(BTWH2"G(2&/X2`-]T$B#QP+H?AX``$B+#=<S``!(BPE(8U7T2(D$
MT4B#^`!U#,=%\/_____II````$B+!;,S``!(BP!(8TWT2(L$R$B)1=A(BT7H
M2(G!2(/!`4B)3>B*`$B+3=B(`0^^R#'`@_D`B$6^=!!(BT78#[X`@_@]#Y7`
MB$6^BD6^J`%U`NL0ZP!(BT782(/``4B)1=CKLTB+1=A(B<%(@\$!2(E-V,8`
M/4B+1>!(B<%(@\$!2(E-X(H`2(M-V$B)RDB#P@%(B578B`$\`'0"Z]C'1?``
M````BT7PB46X9$B+!"4H````2(M-^$@YR'4)BT6X2(/$4%W#Z+`=``!52(GE
M2(/L($B)??A(BWWX2(L%$4,```^^,.@Q'@``2(E%\$B#??``=`Y(BT7P2(/`
M`4B)1>CK"$B+1?A(B47H2(M]Z.B''0``2(/$(%W#D%5(B>5(@>Q`$```9$B+
M!"4H````2(E%^$B)O>#O__](@[W@[___`'0/2(N%X.___P^^`(/X`'482(T]
MTJ'__^@\'0``2(F%Z.___^D]`0``2(N]X.___^A4'0``2(/``4@]`!```'80
M2,>%Z.___P````#I%0$``$B-O?#O__](B[7@[___Z(4=``!(C87P[___2(F%
MT.___TB-O?#O___H"QT``$B)P4B+A=#O__](`<A(@\#_2(F%V.___TB+C=CO
M__](C97P[___,<!(.=&(A<_O__]V'TB+A=CO__\/O@!(BPWO00``#[X).<@/
ME,"(A<_O__^*A<_O__^H`74"ZQY(BX78[___Q@``2(N%V.___TB#P/](B878
M[___ZYQ(C;WP[___2(L%J4$```^^,.C)'```2(F%V.___TB#O=CO__\`=15(
MC3W"H/__Z"P<``!(B87H[___ZS!(BX78[___2(V-\.___T@YR'8*2(N%V.__
M_\8``$B-O?#O___H^AL``$B)A>CO__](BX7H[___2(F%P.___V1(BP0E*```
M`$B+3?A(.<AU$$B+A<#O__](@<1`$```7</HGAL``&9F9F9F+@\?A```````
M54B)Y4B#[!!(C3UUX/__Z#P!``!(C3WFW___Z#`!``!(C3VQH/__Z"0!``!(
MC3V5H/__Z!@!``!(C3T.H?__Z`P!``!(C3UQH?__Z``!``!(C3W)G___Z/0`
M``!(C3V@H/__Z.@```!(C3T>H?__Z-P```!(C3VNG___Z-````!(C3WYH/__
MZ,0```!(C3T0H?__Z`CZ__](B47X2(/X`'002(MU^$B-/>"@___H/OK__TB-
M/=3?___HXOG__TB)1?A(@_@`=!!(BW7X2(T]5J#__^@8^O__2(T]Z:#__^B\
M^?__2(E%^$B#^`!T$DB+=?A(C3TGG___Z/+Y___K*$B-/=R?___HE/G__TB)
M1?A(@_@`=!!(BW7X2(T]XI___^C*^?__ZP!(C3T>H/__2(TU\9___^BU^?__
M2(/$$%W#9F9F9F9F+@\?A```````54B)Y4B#["!D2(L$)2@```!(B47X2(E]
MZ$B+?>A(C77TZ*H7``!(@_@`=$)(BP5-+P``2(L`2&--]$C!X0-(`<A(B47@
M2(M%X$B+0`A(BTW@2(D!2(/X`'4"ZQ#K`$B+1>!(@\`(2(E%X.O9ZZMD2(L$
M)2@```!(BTWX2#G(=09(@\0@7</HM1D```\?1```54B)Y4B#[!!(C3T4G___
MZ*SX__](B47P2(-]\`!T&$B+1?`/O@"#^`!T#$B+1?`/O@"#^#!U"<=%_```
M``#K!\=%_`$```"+1?Q(@\007<-52(GE2(/L$$C'1?@`````2,=%\`````#H
M`QH``(G'Z`P:``!(B47P2(-]\`!T"TB+1?!(BP!(B47X2(M%^$B#Q!!=PV9F
M9BX/'X0``````%5(B>5(@^PP2(E]^$C'1?``````2(T%;MW__TB)1>A(QT7@
M`````$B+?>CH\/?__TB)1?!(@_@`=`](BWWPZ!T9``!(@_@`=1)(BWWH2(MU
M^.@:^/__Z8<```!(BWWP2(MU^.BX&```2(/X`'5R2(M]^.CI&```2(E%T$B+
M/0X^``#HV1@``$B)P4B+1=!(`<A(B4782(M]\.C"&```2(M]V$@!QTB#QP'H
M0A@``$B)1>!(BWW@2(M5^$B+#<\]``!,BT7P2(TU4)[__[``Z/T7``!(BWWH
M2(MUX.B0]___ZP!(@\0P7<,/'X0``````%5(B>5(@>S0`0``9$B+!"4H````
M2(E%^$B)O4C___](QX4X____`````$C'A3#___\`````2,>%*/___P````!(
MBP7)*@``2(E%X$B+!<8J``!(B47H2(L%PRH``$B)1?!(C7VP2(TUQ"H``+HP
M````Z)H7``!(BP7C*@``2(E%D$B+!>`J``!(B4682(L%W2H``$B)1:!(C04W
MG?__2(F%(/___TB-!2><__](B848____2,>%$/___P````!(QX4(____````
M`$C'A0#___\`````2,>%^/[__P````#'A>C^__\`````2(T]P)O__^@[]O__
M2(F%*/___TB#^`!T-DB+O2C____H8A<``$B#^`!T)$B+O2C____H\/W__TB+
MO2C____H%!<``$B)A5#____IF0@``.B#_?__2(F%"/___TB#O0C___\`#X6>
M````QX5$____`````#'`2(.]"/___P"(A;/^__]U($ACA43___](BT3%D$B)
MA3#___](@_@`#Y7`B(6S_O__BH6S_O__J`%U`NM42(N],/___^B*]?__2(F%
M*/___TB#^`!T)4B+O2C____HL18``$B#^`!T$TB+O2C____H;Q8``$B)A0C_
M___K`(N%1/___X/``8F%1/___^EN____ZP!(@[T(____`'4.2(T%QYK__TB)
MA0C___](B[T(____Z%P6``!(B<=(T>=(@\<!Z-T5``!(B87@_O__2(N%"/__
M_TB)A=C^__](BX7@_O__2(F%T/[__TB+A=C^__\/O@"#^`!T14B+O=#^__](
MBX78_O__#[802(TUPMK__[``Z&P5``!(BX78_O__2(/``4B)A=C^__](BX70
M_O__2(/``DB)A=#^___KK$B+A>#^__](B84(____QX5$____`````#'`2(.]
M./___P"(A;+^__]U($ACA43___](BT3%L$B)A3#___](@_@`#Y7`B(6R_O__
MBH6R_O__J`%U`NMG2(N],/___^@T]/__2(F%*/___TB#^`!T.$B+O2C____H
M6Q4``$B#^`!T)DB+O2C____HZ08``(/X`'052(N]*/___^@(%0``2(F%./__
M_^L6ZP"+A43___^#P`&)A43____I6____\>%1/___P`````QP$B#O3C___\`
MB(6Q_O__=3I(8X5$____2(M,Q>!(B8TH____,<!(@_D`B(6Q_O__=!E(B[TH
M____Z-`4``!(@_@`#Y7`B(6Q_O__BH6Q_O__J`%U`NLZ2(N]*/___^A+!@``
M@_@`=!-(B[TH____Z&H4``!(B84X____ZP"+A43___^#P`&)A43____I;O__
M_TB+O3C____H<10``$B)A9C^__](B[T@____Z%X4``!(B<%(BX68_O__2`'(
M2(F%H/[__TB+O0C____H/A0``$B)P4B+A:#^__](`<A(B86H_O__2(N]&/__
M_^@>%```2(G!2(N%J/[__T@!R$@%``0``(F%Z/[__TACO>C^___HB1,``$B)
MA?C^__](B[WX_O__2(N5./___TB+#04Y``!,BX4@____3(N-"/___TB--469
M__^P`.@Q$P``2(N]^/[__[[``0``Z$`4``"#^/]U=>A&%```@S@1=&M(BP62
M*```2(L`2(F%@/[__TB+A4C___](BP!(B86(_O__2(N%^/[__TB)A9#^___H
M#!0``$B+O8#^__](BY6(_O__2(N-D/[__T2+`$B--?J7__^P`.CV$P``2,>%
M4/___P````#IEP0``$B+O?C^___HB@4``(/X`'4Y2(L%%B@``$B+.$B+A4C_
M__](BQ!(BXWX_O__2(TU1=?__[``Z*P3``!(QX50____`````.E-!```2&.]
MZ/[__^AP$@``2(F%`/___TB-/>V7___HC?'__TB)A2C___](@[TH____`'0=
M2(N%2/___TB+.$B+M2C____H=N[__TB)A1#___](@[T0____`'412(N%2/__
M_TB+`$B)A1#___](B[T0____Z'@2``")A<S^___'A<C^__\$````BX7,_O__
M.X7(_O__#XSE````2(N]$/___TACA<S^__](`<=(8XW(_O__,<!(*<A(`<=(
MC35<E___Z!H2``"#^``/A;````"+A<S^__\[A<C^__]T*TB+A1#___^+C<S^
M__\KC<C^__^#Z0%(8\D/O@0(2(L-%S<```^^"3G(=7=(BX5(____2(-X"`!T
M:4B+A4C___](BW@(Z,H1``!(@_@$<E-(BX5(____2(M`"$B)A7C^__](BX5(
M____2(MX".BB$0``2(N]>/[__T@!QTB#Q_Q(C36_EO__Z'@1``"#^`!U$DB+
MA4C___](BT`(2(F%$/___\>%Q/[__P````#H8O?__X/X``^%$P$``$B+O1#_
M__\Q]K``Z`D2``")A?3^__^#^``/A/0```"+O?3^___H7P0``$B)A;C^__](
M@[VX_O__``^,T@```$B+A;C^__](@^@*2(F%N/[__XN]]/[__TB+M;C^__\Q
MTNC$$0``B[WT_O__2(VU6O___[H&````Z+T1``!(C;U:____2(TUFY3__[H&
M````Z+41``"#^`!U3<>%Q/[__P$```!(BX6X_O__2(/H*$B)A;C^__^+O?3^
M__](B[6X_O__,=+H8!$``(N]]/[__TB-M6#___^Z*````.A9$0``QD6(`.LI
M2(V]6O___TB--3B4__^Z!@```.A+$0``@_@`=0K'A<3^__\`````ZP#K`.L`
M@[W$_O__`'0V2(N]`/___TB+E?C^__](BPU0-0``3(V%8/___TR+C1C___](
MC36HU/__L`#H?`\``.DO`0``2(T](Y7__TB--4"5___H!.___TB+A0#___](
MB85@_O__2(N%^/[__TB)A6C^__](BP7Y-```2(F%</[__^@E#P``2(N]8/[_
M_TB+E6C^__](BXUP_O__08G`3(N-&/___TB--=:4__^P`.@(#P``QX6T_O__
M`````$B+O0#___^^P`$``.@-$```B<$QP(/Y_XB%7_[__W41Z`D0``"#.!$/
ME,"(A5_^__^*A5_^__^H`74"ZW=(BX4`____2(F%0/[__TB+A?C^__](B85(
M_O__2(L%5C0``$B)A5#^___H@@X``$B+O4#^__](BY5(_O__2(N-4/[__T&)
MP$2+C;3^__]!@\$!1(F-M/[__TB+A1C___](C34^E/__2(D$)+``Z$\.``#I
M3/___^L`2(N]^/[__^C,#P``2(NU`/___TB-/?Z2___HR>W__TB+O0#____H
M3?7__TB+A0#___](B850____2(N%4/___TB)A3C^__]D2(L$)2@```!(BTWX
M2#G(=1!(BX4X_O__2('$T`$``%W#Z!H.``!F+@\?A```````54B)Y4B![+``
M``!D2(L$)2@```!(B47X2(F]8/___TB+O6#___](C;5H____Z#X/``")P3'`
M@_D`B(5?____=46+18`E`/```#T`0```=!F+38"!X0#P```QP('Y`*```(B%
M7____W4=2(N]8/___[X"````Z`8.``"#^``/E,"(A5____^*A5____\/ML"#
MX`&)A5C___]D2(L$)2@```!(BTWX2#G(=0^+A5C___](@<2P````7</H4@T`
M`&:054B)Y4B![+````!D2(L$)2@```!(B47X2(F]8/___TB+O6#___](C;5H
M____Z'X.``")P3'`@_D`B(5?____=5&+38"!X0#P```QP('Y`$```(B%7___
M_W4XBT6$B858____Z*@-``"+C5C___^)PC'`.=&(A5____]U%HM%@"7_`0``
M/<`!```/E,"(A5____^*A5____\/ML"#X`&)A53___]D2(L$)2@```!(BTWX
M2#G(=0^+A53___](@<2P````7</HA@P``&8/'T0``%5(B>5(@>Q0``$`9$B+
M!"4H````2(E%^(F]Y/_^_XN]Y/_^_S'`B<:Z`@```.AN#0``2(F%P/_^_TB+
MA<#__O](@^@!2(F%N/_^_TB+A<#__O](@^@!N0```0!(F4CW^4B+A;C__O](
M*=!(B878__[_2(.]V/_^_P`/C*````"+O>3__O](B[78__[_,=+H#0T``(N]
MY/_^_TB-M?#__O^Z"``!`.@&#0``B874__[_2(V]\/_^_TACM=3__O](C15#
M,0``N0@```#H80H``$B)A<C__O](@[W(__[_`'0D2(N%V/_^_TB+C<C__O](
MC97P__[_2"G12`'(2(F%Z/_^_^LFZP!(BX78__[_2"T```$`2(F%V/_^_^E2
M____2,>%Z/_^______](BX7H__[_2(F%L/_^_V1(BP0E*````$B+3?A(.<AU
M$$B+A;#__O](@<10``$`7</H(0L``)!52(GE2(/L($B)??A(BWWXZ*OM__](
MB47P2(M]\.A.[?__2(E%Z.A%\?__@_@`=#=(@WWX`'0P2(M]^.@P"P``2(/X
M`'0A2(M]Z$B--820___HV@H``$@[1>AU"4B+??CH"P```.L`2(/$(%W##Q\`
M54B)Y4B![-````!D2(L$)2@```!(B47X2(F]8/___TC'A4C___\`````2(.]
M8/___P!T#$B+A6#___^`.`!U!>EN`0``2(N]8/___^C/"P``2(F%6/___TB#
MO5C___\`=07I3`$``.L`2(N]6/___^B["P``2(F%4/___TB#^``/A!4!``!(
MB[U0____2(/'$TB--<F.___H4PH``(/X``^$\````$B+O5#___](@\<32(TU
M:(___^@S"@``@_@`#X30````2(N]8/___^@N"@``2(/``4B)A3C___](B[U0
M____2(/'$^@3"@``2(G!2(N%./___T@!R$B#P`&)A43___](8[U$____Z(`)
M``!(B85(____2(N]2/___TB+E6#___](BXU0____2(/!$TB-->J-__^P`.@R
M"0``2(N]2/___TB-M6C____HOPD``(/X_W0=BT6`)0#P```]`$```'4.2(N]
M2/___^B/_O__ZPQ(B[U(____Z,$*``!(B[U(____Z'4*``!(QX5(____````
M`.G._O__2(N]6/___^BI"@``2(N]8/___^BM"@``9$B+!"4H````2(M-^$@Y
MR'4)2('$T````%W#Z-T(``!F9F9F+@\?A```````54B)Y4B#[%!(B7WX2(EU
M\,=%T`````!(BPWB'0``9$B+!"4`````2`'(2(L`BHBP````2(L5QAT``&1(
MBP0E`````$@!T$B+`(#A`8B(L0```$B-/32.___H@N?__TB)1<A(@_@`=!E(
MBT7(#[X`@_@Q=0U(BT7(#[Y``8/X`'0%Z+KL__](BPUS'0``9$B+!"4`````
M2`'(2(LX2(TU?HW__[H!````N0,```#HW@D``$B)1>A(@_@`=&](BPT]'0``
M9$B+!"4`````2`'(2(LX2(M%Z$B+0!!(BS!(C14KC?__Z+<)``!(BT7H2(M`
M$$B+`(M`#"4``$``@_@`="9(BPWX'```9$B+!"4`````2`'(2(LX2(M%Z$B+
M0!!(BS#HB0D``.L`ZP!(BPW.'```9$B+!"4`````2`'(2(LX2(TU=HW__[H!
M````N0,```#H.0D``$B)1>A(@_@`#X3#````2,=%P`````!(C3U,C?__Z&?F
M__](B47`2(/X`'0L2(L-=AP``&1(BP0E`````$@!R$B+.$B+1>A(BT`02(LP
M2(M5P.CS"```ZW?H+./__TB)1<!(@WW``'0U2(L-.AP``&1(BP0E`````$@!
MR$B+.$B+1>A(BT`02(LP2(M5P.BW"```2(M]P.@N"```ZS!(BPT%'```9$B+
M!"4`````2`'(2(LX2(M%Z$B+0!!(BS!(BP44+@``2(L0Z'P(``#K`.L`2(L-
MT1L``&1(BP0E`````$@!R$B+`$B)1;A(BPVW&P``9$B+!"4`````2`'(2(LX
M2(TU1XS__[H!````Z%<(``!(BWVX2(G&2(T5@XK__^@D"```2(L-?1L``&1(
MBP0E`````$@!R$B+`,:`L0````!(C3W`BO__Z#OE__](B06,+0``2(,]A"T`
M``!U+4B+/7,M``#H[NW__TB)!6\M``!(@SUG+0```'4.2(T]MHK__[``Z.\'
M``#K`$B+/4XM``"^P`$``.B\!@``B474@WW4`'0N@WW4$70H@WW4_W0B2(L%
M("T``$B+,$B+%1XM``"+3=1(C3W<B?__L`#HI0<``$B#Q%!=PV9F9F9F9BX/
M'X0``````%5(B>5(@^Q`9$B+!"4H````2(E%^,=%W`````")??1(B77H2(E5
MX$B-??1(C77H2(U5X.AH!P``2(L]H1H``$B+%:(:``!(B=;HD@0``$B+!9L:
M``#V``%U2>A1!P``2(D%FBP``$B#/9(L````=0J_`0```.A&!P``2(L]?RP`
M`.A*!P``2(L-,QH``&1(BP0E`````$@!R$B+`,:`M@@```!(BPT6&@``9$B+
M!"4`````2`'(2(L`#[:(.@0``(/)`HB(.@0``$B+#?`9``!D2(L$)0````!(
M`<A(BP`/MH@Z!```@\D!B(@Z!```BT7T@\`#B47,BT7,@\`!2&/X2,'G`^C6
M!@``2(D%WRL``,=%T`````!(BT7H2(L02(L%RBL``(M-T(G.@\8!B7702&/)
M2(D4R$B+!;$K``"+3=")RH/"`8E5T$ACR4B-%?:)__](B13(2(L5H2D``$B+
M!8HK``"+3=")SH/&`8EUT$ACR4B)%,A(BP5Q*P``BTW0B<J#P@&)5=!(8\E(
MC17GB?__2(D4R,=%U`$```"+1=0[1?1],$B+1>A(8TW42(L4R$B+!38K``"+
M3=")SH/&`8EUT$ACR4B)%,B+1=2#P`&)1=3KR$B+!1(K``!(8TW02,<$R```
M``!(BST/*P``BU7,2(L-]2H``$B--:X````QP$&)P.CD!0``B478@WW8`'4/
M2(L]Y"H``.C?!0``B4782(L]U2H``.C@!0``2(T]A8G__^ADXO__2(/X`'4U
M2(,]KBH```!U$TB-/<V'___H2.+__TB)!9DJ``!(@SV1*@```'0,2(L]B"H`
M`.C[]___ZP!(BSV"*@``Z)T%``#HJ`4``(M%V(E%R&1(BP0E*````$B+3?A(
M.<AU"8M%R$B#Q$!=P^CB`@``9I!52(GE2(/L$$B)??A(BPW]%P``9$B+!"4`
M````2`'(2(LXZ"G=__](BPWB%P``9$B+!"4`````2`'(2(LX2(TU$X?__TB-
M%<7Y__],C05!A___13')3(G!Z#,%``!(@\007<-F9F9F+@\?A```````54B)
MY4B#[$!(B7WP2(EUZ$B#??``=`U(BP62%P``2(,X`'4-2,=%^`````#IX```
M`$B+1?!(B4782(M%V`^^"#'`@_D`B$7'=!!(BT78#[X`@_@]#Y7`B$7'BD7'
MJ`%U`NL0ZP!(BT782(/``4B)1=CKQDB+1=A(BTWP2"G(B47D2(L%*!<``$B+
M`$B)1=!(BT702(L`2(E%R$B#^`!T:4B+?<A(BW7P2&-5Y.A_!```@_@`=4-(
MBT7(2&--Y`^^!`B#^#UU,DB+1=!(BPW>%@``2(L)2"G(2,'X`XG!2(M%Z(D(
M2(M%R$AC3>1(`<A(@\`!2(E%^.L8ZP!(BT702(/`"$B)1=#KADC'1?@`````
M2(M%^$B#Q$!=PP\?1```54B)Y4B#[$!(B7WP2(EUZ$B)5>!(B4W82(M%\$B)
M1=!(BT7H2#M%V',*2,=%^`````#K5TB+1=!(`T7H,<E(*TW82`'(2(E%R$B+
M1<A(.T70<C!(BWW(2(MUX$B+5=CH+`(``(/X`'4*2(M%R$B)1?CK&.L`2(M%
MR$B#P/](B47(Z\9(QT7X`````$B+1?A(@\1`7</,S,S,S,S,S,S,S$B+#1$F
M``#I=`,``$B#[`A(BP6I%0``2(7`=`+_T$B#Q`C#`$B#[`A(@\0(PP```/\U
M&B8``/\E'"8```\?0`#_)1HF``!H`````.G@_____R42)@``:`$```#IT/__
M__\E"B8``&@"````Z<#_____)0(F``!H`P```.FP_____R7Z)0``:`0```#I
MH/____\E\B4``&@%````Z9#_____)>HE``!H!@```.F`_____R7B)0``:`<`
M``#I</____\EVB4``&@(````Z6#_____)=(E``!H"0```.E0_____R7*)0``
M:`H```#I0/____\EPB4``&@+````Z3#_____);HE``!H#````.D@_____R6R
M)0``:`T```#I$/____\EJB4``&@.````Z0#_____):(E``!H#P```.GP_O__
M_R6:)0``:!````#IX/[___\EDB4``&@1````Z=#^____)8HE``!H$@```.G`
M_O___R6")0``:!,```#IL/[___\E>B4``&@4````Z:#^____)7(E``!H%0``
M`.F0_O___R5J)0``:!8```#I@/[___\E8B4``&@7````Z7#^____)5HE``!H
M&````.E@_O___R52)0``:!D```#I4/[___\E2B4``&@:````Z4#^____)4(E
M``!H&P```.DP_O___R4Z)0``:!P```#I(/[___\E,B4``&@=````Z1#^____
M)2HE``!H'@```.D`_O___R4B)0``:!\```#I\/W___\E&B4``&@@````Z>#]
M____)1(E``!H(0```.G0_?___R4*)0``:"(```#IP/W___\E`B4``&@C````
MZ;#]____)?HD``!H)````.F@_?___R7R)```:"4```#ID/W___\EZB0``&@F
M````Z8#]____)>(D``!H)P```.EP_?___R7:)```:"@```#I8/W___\ETB0`
M`&@I````Z5#]____)<HD``!H*@```.E`_?___R7")```:"L```#I,/W___\E
MNB0``&@L````Z2#]____);(D``!H+0```.D0_?___R6J)```:"X```#I`/W_
M__\EHB0``&@O````Z?#\____)9HD``!H,````.G@_/___R62)```:#$```#I
MT/S___\EBB0``&@R````Z<#\____)8(D``!H,P```.FP_/___R5Z)```:#0`
M``#IH/S__P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````$`````````
M&0,````````!`````````,P"````````^___;P`````````(`````!4`````
M```````````````'`````````&`-````````"`````````"(`@````````D`
M````````&`````````#Y__]O``````\`````````%P````````#H#P``````
M``(`````````^`0````````#`````````&BV````````%``````````'````
M``````8`````````"`,````````+`````````!@`````````!0`````````T
M"@````````H`````````*0,```````#U_O]O`````!@*````````&0``````
M``"XHP```````!L`````````"``````````:`````````+"C````````'```
M```````(``````````P`````````+)`````````-`````````$20````````
M\/__;P`````@"0```````/[__V\`````I`D```````#___]O``````$`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````"E!!4BYP;0H``````````"BD````````````````````
M`````````&:0````````=I````````"&D````````):0````````II``````
M``"VD````````,:0````````UI````````#FD````````/:0````````!I$`
M```````6D0```````":1````````-I$```````!&D0```````%:1````````
M9I$```````!VD0```````(:1````````EI$```````"FD0```````+:1````
M````QI$```````#6D0```````.:1````````]I$````````&D@```````!:2
M````````)I(````````VD@```````$:2````````5I(```````!FD@``````
M`':2````````AI(```````"6D@```````*:2````````MI(```````#&D@``
M`````-:2````````YI(```````#VD@````````:3````````%I,````````F
MDP```````#:3````````1I,```````!6DP```````&:3````````=I,`````
M``"&DP```````):3````````II,```````!'0T,Z("A'3E4I(#$T+C(N,"`R
M,#(T,#@P,2`H3W!E;DUA;F1R:79A*0!,:6YK97(Z($]P96Y-86YD<FEV82`Q
M.2XQ+C<M,2!,3$0@,3DN,2XW("@O8G5I;&1D:7(O8G5I;&0O0E5)3$0O;&QV
M;2TQ.2XQ+C<M8G5I;&0O;&QV;2UP<F]J96-T+6QL=FUO<F<M,3DN,2XW+VQL
M=FT@9C8U-S=D-V-E960W-61E9C1C-&,W9&(S,&9A,F0S,&$P-3-F8S@U,BD`
M`$]P96Y-86YD<FEV82`Q.2XQ+C<M,2!C;&%N9R!V97)S:6]N(#$Y+C$N-R`H
M+V)U:6QD9&ER+V)U:6QD+T)524Q$+VQL=FTM,3DN,2XW+6)U:6QD+VQL=FTM
M<')O:F5C="UL;'9M;W)G+3$Y+C$N-R]C;&%N9R!F-C4W-V0W8V5E9#<U9&5F
M-&,T8S=D8C,P9F$R9#,P83`U,V9C.#4R*0!'0T,Z("A'3E4I(#$T+C(N,2`R
M,#(U,#0P-2`H3W!E;DUA;F1R:79A*0``+FEN=&5R<``N;F]T92Y!0DDM=&%G
M`"YN;W1E+F=N=2YB=6EL9"UI9``N9'EN<WEM`"YG;G4N=F5R<VEO;@`N9VYU
M+G9E<G-I;VY?<@`N9VYU+FAA<V@`+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N
M<&QT`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+G1E>'0`+FEN
M:70`+F9I;FD`+G!L=``N9FEN:5]A<G)A>0`N:6YI=%]A<G)A>0`N9&%T82YR
M96PN<F\`+F1Y;F%M:6,`+F=O=``N<F5L<F]?<&%D9&EN9P`N=&U?8VQO;F5?
M=&%B;&4`+F1A=&$`+F=O="YP;'0`+F)S<P`N8V]M;65N=``N<VAS=')T86(`
M````````````````````````````````````````````````````````````
M`````````````````````````````0````$````"`````````*@"````````
MJ`(````````<`````````````````````0````````````````````D````'
M`````@````````#$`@```````,0"````````(`````````````````````0`
M```````````````````7````!P````(`````````Y`(```````#D`@``````
M`"0````````````````````$````````````````````*@````L````"````
M``````@#````````"`,````````8!@````````@````!````"``````````8
M`````````#(```#___]O`@`````````@"0```````"`)````````@@``````
M```$``````````(``````````@`````````_````_O__;P(`````````I`D`
M``````"D"0```````'``````````"`````$````$````````````````````
M3@```/;__V\"`````````!@*````````&`H````````<``````````0`````
M````"````````````````````%@````#`````@`````````T"@```````#0*
M````````*0,```````````````````$```````````````````!@````!```
M``(`````````8`T```````!@#0```````(@"````````!``````````(````
M`````!@`````````:@````0```!"`````````.@/````````Z`\```````#X
M!`````````0````:````"``````````8`````````'0````!````,@``````
M``#@%````````.`4````````!$$```````````````````$`````````````
M``````!\`````0````(`````````Y%4```````#D50```````-P`````````
M```````````$````````````````````B@````$````"`````````,!6````
M````P%8```````"0`P``````````````````"````````````````````)0`
M```!````!@````````!0:@```````%!:````````W"4`````````````````
M`!````````````````````":`````0````8`````````+)`````````L@```
M`````!<````````````````````$````````````````````H`````$````&
M`````````$20````````1(`````````)````````````````````!```````
M`````````````*8````!````!@````````!0D````````%"`````````8`,`
M`````````````````!````````````````````"K````#P````,`````````
ML*,```````"P@P````````@````````````````````(``````````@`````
M````MP````X````#`````````+BC````````N(,````````(````````````
M````````"``````````(`````````,,````!`````P````````#`HP``````
M`,"#````````:````````````````````!````````````````````#0````
M!@````,`````````**0````````HA````````+`!````````"``````````(
M`````````!``````````V0````$````#`````````-BE````````V(4`````
M``!@````````````````````"````````````````````-X````(`````P``
M```````XI@```````#B&````````R`D```````````````````$`````````
M``````````#M`````0````,`````````.+8````````XA@``````````````
M```````````````(````````````````````_0````$````#`````````#BV
M````````.(8````````I````````````````````"```````````````````
M``,!```!`````P````````!HM@```````&B&````````P`$`````````````
M``````@````````````````````,`0``"`````,`````````*+@````````H
MB````````"0````````````````````(````````````````````$0$```$`
M```P````````````````````*(@```````"2`0```````````````````0``
M```````!`````````!H!```#`````````````````````````+J)````````
@)`$```````````````````$`````````````````````
